@@ -1,5 +1,6 @@
+from __future__ import annotations
 import typing as t
-from typing import overload
+from collections.abc import KeysView
 from abc import ABCMeta, abstractmethod
 from .types import DictKey, AnyKey, KeyParameters
 from ..registry import (
@@ -79,10 +80,11 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
     value_registry: t.ClassVar[KeyParameterRegistryDict]
     param_registry: t.ClassVar[KeyParameterRegistryDict] = JWK_PARAMETER_REGISTRY
     operation_registry: t.ClassVar[KeyOperationRegistryDict] = JWK_OPERATION_REGISTRY
+    thumbprint_digest_method: t.ClassVar[t.Literal["sha256", "sha384", "sha512"]] = 'sha256'
 
     def __init__(
             self,
-            raw_value: t.Union[NativePrivateKey, NativePublicKey],
+            raw_value: NativePrivateKey | NativePublicKey,
             original_value: t.Any,
             parameters: t.Optional[KeyParameters] = None):
         self._raw_value = raw_value
@@ -97,13 +99,13 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
             self.validate_dict_key(data)
             self._dict_value = data
 
-    def keys(self):
+    def keys(self) -> KeysView[str]:
         return self.dict_value.keys()
 
-    def __getitem__(self, k: str):
+    def __getitem__(self, k: str) -> str | list[str]:
         return self.dict_value[k]
 
-    def get(self, k: str, default=None):
+    def get(self, k: str, default: str | None = None) -> str | list[str] | None:
         return self.dict_value.get(k, default)
 
     def ensure_kid(self) -> None:
@@ -114,11 +116,17 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
             self._dict_value["kid"] = self.thumbprint()
 
     @property
-    def kid(self) -> t.Optional[str]:
-        return self.get("kid")
+    def kid(self) -> str | None:
+        """The "kid" value of the JSON Web Key."""
+        return t.cast(t.Optional[str], self.get("kid"))
 
     @property
-    def raw_value(self):
+    def alg(self) -> str | None:
+        """The "alg" value of the JSON Web Key."""
+        return t.cast(t.Optional[str], self.get("alg"))
+
+    @property
+    def raw_value(self) -> t.Any:
         raise NotImplementedError()
 
     @property
@@ -152,7 +160,7 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
         defined in RFC7638."""
         fields = [k for k in self.value_registry if self.value_registry[k].required]
         fields.append("kty")
-        return thumbprint(self.dict_value, fields)
+        return thumbprint(self.dict_value, fields, self.thumbprint_digest_method)
 
     def as_dict(self, private: t.Optional[bool] = None, **params: t.Any) -> DictKey:
         """Output this key to a JWK format (in dict). By default, it will return
@@ -214,13 +222,13 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
         if reg.private and not self.is_private:
             raise UnsupportedKeyOperationError(f'Invalid key_op "{operation}" for public key')
 
-    @overload
+    @t.overload
     def get_op_key(self, operation: t.Literal["verify", "encrypt", "wrapKey", "deriveKey"]) -> NativePublicKey: ...
 
-    @overload
+    @t.overload
     def get_op_key(self, operation: t.Literal["sign", "decrypt", "unwrapKey"]) -> NativePrivateKey: ...
 
-    def get_op_key(self, operation: str) -> t.Union[NativePublicKey, NativePrivateKey]:
+    def get_op_key(self, operation: str) -> NativePublicKey | NativePrivateKey:
         self.check_key_op(operation)
         reg = self.operation_registry[operation]
         if reg.private:
@@ -229,7 +237,7 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
         return self.public_key
 
     @classmethod
-    def validate_dict_key(cls, data: DictKey):
+    def validate_dict_key(cls, data: DictKey) -> None:
         cls.binding.validate_dict_key_registry(data, cls.param_registry)
         cls.binding.validate_dict_key_registry(data, cls.value_registry)
         cls.binding.validate_dict_key_use_operations(data)
@@ -251,7 +259,7 @@ class BaseKey(t.Generic[NativePrivateKey, NativePublicKey], metaclass=ABCMeta):
     @classmethod
     def generate_key(
             cls: t.Type[GenericKey],
-            size_or_crv,
+            size_or_crv: t.Any,
             parameters: t.Optional[KeyParameters] = None,
             private: bool = True,
             auto_kid: bool = False) -> GenericKey:
@@ -306,5 +314,5 @@ class CurveKey(AsymmetricKey[NativePrivateKey, NativePublicKey]):
         pass
 
     @abstractmethod
-    def exchange_derive_key(self, key) -> bytes:
+    def exchange_derive_key(self, key: t.Any) -> bytes:
         pass
