@@ -1,6 +1,6 @@
-import random
-import string
-import typing as t
+from __future__ import annotations
+from typing import Any
+from os import urandom
 from ..util import (
     to_bytes,
     urlsafe_b64decode,
@@ -13,7 +13,9 @@ from ..rfc7517.types import KeyParameters, DictKey
 
 POSSIBLE_UNSAFE_KEYS = (
     b"-----BEGIN ",
+    b"---- BEGIN ",
     b"ssh-rsa ",
+    b"ssh-dss ",
     b"ssh-ed25519 ",
     b"ecdsa-sha2-",
 )
@@ -30,7 +32,7 @@ class OctBinding(NativeKeyBinding):
         return urlsafe_b64decode(to_bytes(value["k"]))
 
     @classmethod
-    def import_from_bytes(cls, value: bytes, password: t.Optional[t.Any] = None) -> bytes:
+    def import_from_bytes(cls, value: bytes, password: Any | None = None) -> bytes:
         # security check
         if value.startswith(POSSIBLE_UNSAFE_KEYS):
             raise ValueError("This key may not be safe to import")
@@ -50,7 +52,7 @@ class OctKey(SymmetricKey):
     def generate_key(
             cls,
             key_size: int = 256,
-            parameters: t.Optional[KeyParameters] = None,
+            parameters: KeyParameters | None = None,
             private: bool = True,
             auto_kid: bool = False) -> "OctKey":
         """Generate a ``OctKey`` with the given bit size (not bytes).
@@ -66,10 +68,7 @@ class OctKey(SymmetricKey):
         if key_size % 8 != 0:
             raise ValueError("Invalid bit size for oct key")
 
-        length = key_size // 8
-        rand = random.SystemRandom()
-        chars = string.ascii_letters + string.digits
-        value = "".join(rand.choice(chars) for _ in range(length))
+        value = urandom(key_size // 8)
         raw_key = to_bytes(value)
         key: OctKey = cls(raw_key, raw_key, parameters)
         if auto_kid:
